@@ -57,10 +57,10 @@ class Keil5P27Converter(Converter):
     def analyze_project(self, prj_files: dict, target_name: str = '', output_file: str = '') -> dict:
         # 检查工程文件配置有效性
         if 'uvprojx' not in prj_files.keys() or prj_files['uvprojx'] is None:
-            raise Exception('Keil 5 project file(*.uvprojx) not found!')
+            raise FileNotFoundError('Keil 5 project file(*.uvprojx) not found!')
 
         if 'uvoptx' not in prj_files.keys() or prj_files['uvoptx'] is None:
-            raise Exception('Keil 5 project options file(*.uvoptx) not found!')
+            raise FileNotFoundError('Keil 5 project options file(*.uvoptx) not found!')
 
         # ---------------- 加载工程描述文件模板 ----------------
         prj_desc = self.load_template(self)
@@ -75,7 +75,7 @@ class Keil5P27Converter(Converter):
         project_xml = f.read()
         f.close()
 
-        project = xmltodict.parse(project_xml, force_list=('Target', 'File'))
+        project = xmltodict.parse(project_xml, force_list=('Target', 'File', 'Group'))
 
         # 读取工程选项文件
         f = open(prj_files['uvoptx'], 'rb')  # 先用二进制打开以获取编码
